/* Generated automatically by the program `genconditions' from the target
   machine description file.  */

#define IN_TARGET_CODE 1
#include "bconfig.h"
#define INCLUDE_STRING
#include "system.h"

/* It is necessary, but not entirely safe, to include the headers below
   in a generator program.  As a defensive measure, don't do so when the
   table isn't going to have anything in it.  */
#if GCC_VERSION >= 3001

/* Do not allow checking to confuse the issue.  */
#undef CHECKING_P
#define CHECKING_P 0
#undef ENABLE_TREE_CHECKING
#undef ENABLE_RTL_CHECKING
#undef ENABLE_RTL_FLAG_CHECKING
#undef ENABLE_GC_CHECKING
#undef ENABLE_GC_ALWAYS_COLLECT
#define USE_ENUM_MODES

#include "coretypes.h"
#include "tm.h"
#include "insn-constants.h"
#include "rtl.h"
#include "memmodel.h"
#include "tm_p.h"
#include "hard-reg-set.h"
#include "function.h"
#include "emit-rtl.h"

/* Fake - insn-config.h doesn't exist yet.  */
#define MAX_RECOG_OPERANDS 10
#define MAX_DUP_OPERANDS 10
#define MAX_INSNS_PER_SPLIT 5

#include "regs.h"
#include "recog.h"
#include "output.h"
#include "flags.h"
#include "hard-reg-set.h"
#include "predict.h"
#include "basic-block.h"
#include "bitmap.h"
#include "df.h"
#include "resource.h"
#include "diagnostic-core.h"
#include "reload.h"
#include "tm-constrs.h"

#define HAVE_eh_return 1
#include "except.h"

/* Dummy external declarations.  */
extern rtx_insn *insn;
extern rtx ins1;
extern rtx operands[];

#endif /* gcc >= 3.0.1 */

/* Structure definition duplicated from gensupport.h rather than
   drag in that file and its dependencies.  */
struct c_test
{
  const char *expr;
  int value;
};

/* This table lists each condition found in the machine description.
   Each condition is mapped to its truth value (0 or 1), or -1 if that
   cannot be calculated at compile time.
   If we don't have __builtin_constant_p, or it's not acceptable in array
   initializers, fall back to assuming that all conditions potentially
   vary at run time.  It works in 3.0.1 and later; 3.0 only when not
   optimizing.  */

#if GCC_VERSION >= 3001
static const struct c_test insn_conditions[] = {

#line 855 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "!TARGET_SOFT_MUL && TARGET_MULTIPLY_HIGH",
    __builtin_constant_p 
#line 855 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_SOFT_MUL && TARGET_MULTIPLY_HIGH)
    ? (int) 
#line 855 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_SOFT_MUL && TARGET_MULTIPLY_HIGH)
    : -1 },
#line 1866 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "reload_completed\n\
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))\n\
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1]))\n\
   && (REGNO (operands[0]) == (REGNO (operands[1]) + 1))\n\
   && !TARGET_MB_64",
    __builtin_constant_p 
#line 1866 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(reload_completed
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1]))
   && (REGNO (operands[0]) == (REGNO (operands[1]) + 1))
   && !TARGET_MB_64)
    ? (int) 
#line 1866 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(reload_completed
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1]))
   && (REGNO (operands[0]) == (REGNO (operands[1]) + 1))
   && !TARGET_MB_64)
    : -1 },
#line 1878 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "reload_completed\n\
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))\n\
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1]))\n\
   && (REGNO (operands[0]) != (REGNO (operands[1]) + 1))\n\
   && !TARGET_MB_64",
    __builtin_constant_p 
#line 1878 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(reload_completed
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1]))
   && (REGNO (operands[0]) != (REGNO (operands[1]) + 1))
   && !TARGET_MB_64)
    ? (int) 
#line 1878 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(reload_completed
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1]))
   && (REGNO (operands[0]) != (REGNO (operands[1]) + 1))
   && !TARGET_MB_64)
    : -1 },
#line 2079 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "(INTVAL (operands[2]) > 17 && !optimize_size)",
    __builtin_constant_p 
#line 2079 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((INTVAL (operands[2]) > 17 && !optimize_size))
    ? (int) 
#line 2079 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((INTVAL (operands[2]) > 17 && !optimize_size))
    : -1 },
#line 3659 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_HAS_BITFIELD && UINTVAL (operands[1]) > 0\n\
   && UINTVAL (operands[1]) + UINTVAL (operands[2]) <= 32",
    __builtin_constant_p 
#line 3659 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HAS_BITFIELD && UINTVAL (operands[1]) > 0
   && UINTVAL (operands[1]) + UINTVAL (operands[2]) <= 32)
    ? (int) 
#line 3659 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HAS_BITFIELD && UINTVAL (operands[1]) > 0
   && UINTVAL (operands[1]) + UINTVAL (operands[2]) <= 32)
    : -1 },
#line 1544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "(register_operand (operands[0], SImode) && \n\
           (GET_CODE (operands[1]) == CONST_INT && \n\
                 (INTVAL (operands[1]) <= 32767 && INTVAL (operands[1]) >= -32768)))",
    __builtin_constant_p 
#line 1544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((register_operand (operands[0], SImode) && 
           (GET_CODE (operands[1]) == CONST_INT && 
                 (INTVAL (operands[1]) <= 32767 && INTVAL (operands[1]) >= -32768))))
    ? (int) 
#line 1544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((register_operand (operands[0], SImode) && 
           (GET_CODE (operands[1]) == CONST_INT && 
                 (INTVAL (operands[1]) <= 32767 && INTVAL (operands[1]) >= -32768))))
    : -1 },
#line 2043 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "!TARGET_SOFT_MUL",
    __builtin_constant_p 
#line 2043 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_SOFT_MUL)
    ? (int) 
#line 2043 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_SOFT_MUL)
    : -1 },
#line 3638 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_HAS_BITFIELD",
    __builtin_constant_p 
#line 3638 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HAS_BITFIELD)
    ? (int) 
#line 3638 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HAS_BITFIELD)
    : -1 },
#line 3406 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "flag_pic && TARGET_MB_64",
    __builtin_constant_p 
#line 3406 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(flag_pic && TARGET_MB_64)
    ? (int) 
#line 3406 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(flag_pic && TARGET_MB_64)
    : -1 },
#line 903 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "!TARGET_SOFT_DIV",
    __builtin_constant_p 
#line 903 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_SOFT_DIV)
    ? (int) 
#line 903 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_SOFT_DIV)
    : -1 },
#line 814 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "!TARGET_SOFT_MUL && TARGET_MULTIPLY_HIGH && !TARGET_MB_64",
    __builtin_constant_p 
#line 814 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_SOFT_MUL && TARGET_MULTIPLY_HIGH && !TARGET_MB_64)
    ? (int) 
#line 814 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_SOFT_MUL && TARGET_MULTIPLY_HIGH && !TARGET_MB_64)
    : -1 },
#line 2660 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_HARD_FLOAT",
    __builtin_constant_p 
#line 2660 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HARD_FLOAT)
    ? (int) 
#line 2660 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HARD_FLOAT)
    : -1 },
#line 3627 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_HAS_BITFIELD && (UINTVAL (operands[2]) > 0)\n\
   && ((UINTVAL (operands[2]) + UINTVAL (operands[3])) <= 32)",
    __builtin_constant_p 
#line 3627 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HAS_BITFIELD && (UINTVAL (operands[2]) > 0)
   && ((UINTVAL (operands[2]) + UINTVAL (operands[3])) <= 32))
    ? (int) 
#line 3627 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HAS_BITFIELD && (UINTVAL (operands[2]) > 0)
   && ((UINTVAL (operands[2]) + UINTVAL (operands[3])) <= 32))
    : -1 },
#line 1375 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_MB_64 && (register_operand (operands[0], Pmode) && \n\
           PLT_ADDR_P (operands[1]))",
    __builtin_constant_p 
#line 1375 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && (register_operand (operands[0], Pmode) && 
           PLT_ADDR_P (operands[1])))
    ? (int) 
#line 1375 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && (register_operand (operands[0], Pmode) && 
           PLT_ADDR_P (operands[1])))
    : -1 },
#line 608 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_MB_64 && TARGET_HARD_FLOAT && TARGET_FLOAT_CONVERT",
    __builtin_constant_p 
#line 608 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && TARGET_HARD_FLOAT && TARGET_FLOAT_CONVERT)
    ? (int) 
#line 608 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && TARGET_HARD_FLOAT && TARGET_FLOAT_CONVERT)
    : -1 },
#line 521 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_HARD_FLOAT && TARGET_FLOAT_SQRT",
    __builtin_constant_p 
#line 521 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HARD_FLOAT && TARGET_FLOAT_SQRT)
    ? (int) 
#line 521 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HARD_FLOAT && TARGET_FLOAT_SQRT)
    : -1 },
#line 2563 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_MB_64 && TARGET_PATTERN_COMPARE",
    __builtin_constant_p 
#line 2563 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && TARGET_PATTERN_COMPARE)
    ? (int) 
#line 2563 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && TARGET_PATTERN_COMPARE)
    : -1 },
#line 1559 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "(register_operand (operands[0], Pmode) && \n\
           PLT_ADDR_P (operands[1]))",
    __builtin_constant_p 
#line 1559 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((register_operand (operands[0], Pmode) && 
           PLT_ADDR_P (operands[1])))
    ? (int) 
#line 1559 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((register_operand (operands[0], Pmode) && 
           PLT_ADDR_P (operands[1])))
    : -1 },
#line 1121 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_MB_64 && ((long long)INTVAL(operands[2]) > (long long)-32768) && ((long long) INTVAL(operands[2]) < (long long)32767)",
    __builtin_constant_p 
#line 1121 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && ((long long)INTVAL(operands[2]) > (long long)-32768) && ((long long) INTVAL(operands[2]) < (long long)32767))
    ? (int) 
#line 1121 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && ((long long)INTVAL(operands[2]) > (long long)-32768) && ((long long) INTVAL(operands[2]) < (long long)32767))
    : -1 },
#line 539 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_HARD_FLOAT && TARGET_FLOAT_CONVERT",
    __builtin_constant_p 
#line 539 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HARD_FLOAT && TARGET_FLOAT_CONVERT)
    ? (int) 
#line 539 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HARD_FLOAT && TARGET_FLOAT_CONVERT)
    : -1 },
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_BARREL_SHIFT",
    __builtin_constant_p 
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_BARREL_SHIFT)
    ? (int) 
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_BARREL_SHIFT)
    : -1 },
#line 1693 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_REORDER",
    __builtin_constant_p 
#line 1693 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_REORDER)
    ? (int) 
#line 1693 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_REORDER)
    : -1 },
#line 2471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "(INTVAL (operands[2]) > 5 && optimize_size)",
    __builtin_constant_p 
#line 2471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((INTVAL (operands[2]) > 5 && optimize_size))
    ? (int) 
#line 2471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((INTVAL (operands[2]) > 5 && optimize_size))
    : -1 },
#line 1348 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "microblaze_is_interrupt_variant () && TARGET_MB_64",
    __builtin_constant_p 
#line 1348 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(microblaze_is_interrupt_variant () && TARGET_MB_64)
    ? (int) 
#line 1348 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(microblaze_is_interrupt_variant () && TARGET_MB_64)
    : -1 },
#line 2027 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "!TARGET_SOFT_MUL \n\
   && ((1 << INTVAL (operands[2])) <= 32767 && (1 << INTVAL (operands[2])) >= -32768)",
    __builtin_constant_p 
#line 2027 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_SOFT_MUL 
   && ((1 << INTVAL (operands[2])) <= 32767 && (1 << INTVAL (operands[2])) >= -32768))
    ? (int) 
#line 2027 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_SOFT_MUL 
   && ((1 << INTVAL (operands[2])) <= 32767 && (1 << INTVAL (operands[2])) >= -32768))
    : -1 },
#line 712 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_PREFETCH && !TARGET_MB_64",
    __builtin_constant_p 
#line 712 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_PREFETCH && !TARGET_MB_64)
    ? (int) 
#line 712 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_PREFETCH && !TARGET_MB_64)
    : -1 },
#line 2372 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_MB_64 && TARGET_BARREL_SHIFT",
    __builtin_constant_p 
#line 2372 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && TARGET_BARREL_SHIFT)
    ? (int) 
#line 2372 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && TARGET_BARREL_SHIFT)
    : -1 },
#line 3113 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "!TARGET_MB_64",
    __builtin_constant_p 
#line 3113 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_MB_64)
    ? (int) 
#line 3113 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(!TARGET_MB_64)
    : -1 },
#line 1482 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "reload_completed \n\
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))\n\
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1])) \n\
   && (REGNO(operands[0]) == (REGNO(operands[1]) + 1))\n\
   && !(TARGET_MB_64)",
    __builtin_constant_p 
#line 1482 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(reload_completed 
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1])) 
   && (REGNO(operands[0]) == (REGNO(operands[1]) + 1))
   && !(TARGET_MB_64))
    ? (int) 
#line 1482 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(reload_completed 
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1])) 
   && (REGNO(operands[0]) == (REGNO(operands[1]) + 1))
   && !(TARGET_MB_64))
    : -1 },
#line 870 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "(!TARGET_SOFT_DIV) || (TARGET_BARREL_SHIFT && TARGET_SMALL_DIVIDES)",
    __builtin_constant_p 
#line 870 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((!TARGET_SOFT_DIV) || (TARGET_BARREL_SHIFT && TARGET_SMALL_DIVIDES))
    ? (int) 
#line 870 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((!TARGET_SOFT_DIV) || (TARGET_BARREL_SHIFT && TARGET_SMALL_DIVIDES))
    : -1 },
#line 3130 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "microblaze_can_use_return_insn ()",
    __builtin_constant_p 
#line 3130 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(microblaze_can_use_return_insn ())
    ? (int) 
#line 3130 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(microblaze_can_use_return_insn ())
    : -1 },
#line 2891 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_MB_64",
    __builtin_constant_p 
#line 2891 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64)
    ? (int) 
#line 2891 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64)
    : -1 },
#line 3580 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_HAS_CLZ",
    __builtin_constant_p 
#line 3580 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HAS_CLZ)
    ? (int) 
#line 3580 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_HAS_CLZ)
    : -1 },
#line 2539 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_PATTERN_COMPARE",
    __builtin_constant_p 
#line 2539 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_PATTERN_COMPARE)
    ? (int) 
#line 2539 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_PATTERN_COMPARE)
    : -1 },
#line 738 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_MB_64 && ((long long)INTVAL(operands[2]) > (long long)-32768) && ((long long) INTVAL(operands[2]) < (long long)32767) && (REGNO (operands[0]) == REGNO (operands[1]))",
    __builtin_constant_p 
#line 738 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && ((long long)INTVAL(operands[2]) > (long long)-32768) && ((long long) INTVAL(operands[2]) < (long long)32767) && (REGNO (operands[0]) == REGNO (operands[1])))
    ? (int) 
#line 738 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && ((long long)INTVAL(operands[2]) > (long long)-32768) && ((long long) INTVAL(operands[2]) < (long long)32767) && (REGNO (operands[0]) == REGNO (operands[1])))
    : -1 },
#line 1531 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "microblaze_is_interrupt_variant ()",
    __builtin_constant_p 
#line 1531 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(microblaze_is_interrupt_variant ())
    ? (int) 
#line 1531 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(microblaze_is_interrupt_variant ())
    : -1 },
#line 2446 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "(operands[2] == const1_rtx)",
    __builtin_constant_p 
#line 2446 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((operands[2] == const1_rtx))
    ? (int) 
#line 2446 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((operands[2] == const1_rtx))
    : -1 },
#line 1028 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "reload_completed \n\
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))\n\
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1]))\n\
   && !TARGET_MB_64",
    __builtin_constant_p 
#line 1028 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(reload_completed 
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1]))
   && !TARGET_MB_64)
    ? (int) 
#line 1028 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(reload_completed 
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1]))
   && !TARGET_MB_64)
    : -1 },
#line 1495 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "reload_completed \n\
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))\n\
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1])) \n\
   && (REGNO (operands[0]) != (REGNO (operands[1]) + 1))\n\
   && !(TARGET_MB_64)",
    __builtin_constant_p 
#line 1495 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(reload_completed 
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1])) 
   && (REGNO (operands[0]) != (REGNO (operands[1]) + 1))
   && !(TARGET_MB_64))
    ? (int) 
#line 1495 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(reload_completed 
   && GET_CODE (operands[0]) == REG && GP_REG_P (REGNO (operands[0]))
   && GET_CODE (operands[1]) == REG && GP_REG_P (REGNO (operands[1])) 
   && (REGNO (operands[0]) != (REGNO (operands[1]) + 1))
   && !(TARGET_MB_64))
    : -1 },
#line 3036 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_MB_64 && NEXT_INSN (as_a <rtx_insn *> (operands[1])) != 0\n\
  && GET_CODE (PATTERN (NEXT_INSN (as_a <rtx_insn *> (operands[1])))) == ADDR_DIFF_VEC\n\
  && flag_pic",
    __builtin_constant_p 
#line 3036 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && NEXT_INSN (as_a <rtx_insn *> (operands[1])) != 0
  && GET_CODE (PATTERN (NEXT_INSN (as_a <rtx_insn *> (operands[1])))) == ADDR_DIFF_VEC
  && flag_pic)
    ? (int) 
#line 3036 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && NEXT_INSN (as_a <rtx_insn *> (operands[1])) != 0
  && GET_CODE (PATTERN (NEXT_INSN (as_a <rtx_insn *> (operands[1])))) == ADDR_DIFF_VEC
  && flag_pic)
    : -1 },
#line 3396 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "flag_pic",
    __builtin_constant_p 
#line 3396 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(flag_pic)
    ? (int) 
#line 3396 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(flag_pic)
    : -1 },
#line 3011 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "NEXT_INSN (as_a <rtx_insn *> (operands[1])) != 0\n\
  && GET_CODE (PATTERN (NEXT_INSN (as_a <rtx_insn *> (operands[1])))) == ADDR_DIFF_VEC\n\
  && flag_pic",
    __builtin_constant_p 
#line 3011 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(NEXT_INSN (as_a <rtx_insn *> (operands[1])) != 0
  && GET_CODE (PATTERN (NEXT_INSN (as_a <rtx_insn *> (operands[1])))) == ADDR_DIFF_VEC
  && flag_pic)
    ? (int) 
#line 3011 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(NEXT_INSN (as_a <rtx_insn *> (operands[1])) != 0
  && GET_CODE (PATTERN (NEXT_INSN (as_a <rtx_insn *> (operands[1])))) == ADDR_DIFF_VEC
  && flag_pic)
    : -1 },
#line 1361 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "TARGET_MB_64 && (register_operand (operands[0], DImode) && \n\
           (GET_CODE (operands[1]) == CONST_INT))",
    __builtin_constant_p 
#line 1361 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && (register_operand (operands[0], DImode) && 
           (GET_CODE (operands[1]) == CONST_INT)))
    ? (int) 
#line 1361 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
(TARGET_MB_64 && (register_operand (operands[0], DImode) && 
           (GET_CODE (operands[1]) == CONST_INT)))
    : -1 },
#line 1726 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
  { "(register_operand (operands[0], SFmode)\n\
       || register_operand (operands[1], SFmode)\n\
       || operands[1] == CONST0_RTX (SFmode))",
    __builtin_constant_p 
#line 1726 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((register_operand (operands[0], SFmode)
       || register_operand (operands[1], SFmode)
       || operands[1] == CONST0_RTX (SFmode)))
    ? (int) 
#line 1726 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
((register_operand (operands[0], SFmode)
       || register_operand (operands[1], SFmode)
       || operands[1] == CONST0_RTX (SFmode)))
    : -1 },

};
#endif /* gcc >= 3.0.1 */

int
main(void)
{
  unsigned int i;
  const char *p;
  puts ("(define_conditions [");
#if GCC_VERSION >= 3001
  for (i = 0; i < ARRAY_SIZE (insn_conditions); i++)
    {
      printf ("  (%d \"", insn_conditions[i].value);
      for (p = insn_conditions[i].expr; *p; p++)
        {
          switch (*p)
	     {
	     case '\\':
	     case '\"': putchar ('\\'); break;
	     default: break;
	     }
          putchar (*p);
        }
      puts ("\")");
    }
#endif /* gcc >= 3.0.1 */
  puts ("])");
  fflush (stdout);
return ferror (stdout) != 0 ? FATAL_EXIT_CODE : SUCCESS_EXIT_CODE;
}
